**********************
Data Analysis Routines
**********************
These modules provide basic data analysis or data fitting functionality.

linefit
=======
.. automodule:: stsci.tools.linefit
   :members:

nmpfit
======   
.. automodule:: stsci.tools.nmpfit
   :members:
   
xyinterp
========
.. automodule:: stsci.tools.xyinterp
   :members:

gfit
====
.. automodule:: stsci.tools.gfit
   :members:
   
Image Combination Modules
*************************
The `numcombine` module serves as a limited replacement for IRAF's 'imcombine' task.

.. automodule:: stsci.image.numcombine
   :members:
   :undoc-members:
